@@ -20,6 +20,7 @@ use NewsExtractor::SiteSpecificExtractor::www_rti_org_tw;
 use NewsExtractor::SiteSpecificExtractor::www_bcc_com_tw;
 use NewsExtractor::SiteSpecificExtractor::www_setn_com;
 use NewsExtractor::SiteSpecificExtractor::news_tnn_tw;
+use NewsExtractor::SiteSpecificExtractor::turnnewsapp_com;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 
@@ -57,6 +58,7 @@ use constant {
         'www.bcc.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_bcc_com_tw',
         'www.setn.com' => 'NewsExtractor::SiteSpecificExtractor::www_setn_com',
         'news.tnn.tw' => 'NewsExtractor::SiteSpecificExtractor::news_tnn_tw',
+        'turnnewsapp.com' => 'NewsExtractor::SiteSpecificExtractor::turnnewsapp_com',
     },
     CSSRuleSetByHost => {
         'udn.com' => {
