@@ -1,6 +1,8 @@
 package NewsExtractor::Types;
 use v5.18;
 
+use Importer 'NewsExtractor::Constants' => 'NEWSPAPER_NAMES';
+
 use Type::Library -base;
 use Type::Utils -all;
 extends "Types::Standard";
@@ -9,4 +11,6 @@ declare Text   => as "Str",  where { defined($_) && ($_ eq '' || utf8::is_utf8($
 declare Text1K => as "Text", where { length($_) <= 1024 };
 declare Text4K => as "Text", where { length($_) <= 4096 };
 
+enum NewspaperName => NEWSPAPER_NAMES;
+
 1;
